==> haskell-basic-prelude-0.7.0-384.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-basic-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 basic-prelude
version:              0.7.0
visibility:           public
id:                   basic-prelude-0.7.0-5kW5qAv1DXmG0ZyMhJUVxr
key:                  basic-prelude-0.7.0-5kW5qAv1DXmG0ZyMhJUVxr
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Dan Burton
homepage:             https://github.com/snoyberg/basic-prelude#readme
synopsis:
    An enhanced core prelude; a common foundation for alternate preludes.

description:
    Please see the README on Github at <https://github.com/snoyberg/basic-prelude#readme>

category:             Control, Prelude
abi:                  a3cf35b6cc17b303ac01c739f3514e0d
exposed:              True
exposed-modules:      BasicPrelude CorePrelude
hidden-modules:       Paths_basic_prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/basic-prelude-0.7.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/basic-prelude-0.7.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/basic-prelude-0.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-basic-prelude
hs-libraries:         HSbasic-prelude-0.7.0-5kW5qAv1DXmG0ZyMhJUVxr
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    filepath-1.4.300.1 hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-basic-prelude/html/basic-prelude.haddock

haddock-html:         /usr/share/doc/haskell-basic-prelude/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-basic-prelude-0.7.0-385-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-basic-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 basic-prelude
version:              0.7.0
visibility:           public
id:                   basic-prelude-0.7.0-AWll56bMwLJADdeHnl7DBM
key:                  basic-prelude-0.7.0-AWll56bMwLJADdeHnl7DBM
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Dan Burton
homepage:             https://github.com/snoyberg/basic-prelude#readme
synopsis:
    An enhanced core prelude; a common foundation for alternate preludes.

description:
    Please see the README on Github at <https://github.com/snoyberg/basic-prelude#readme>

category:             Control, Prelude
abi:                  953aa16b95cfa061fc91962ac77f603c
exposed:              True
exposed-modules:      BasicPrelude CorePrelude
hidden-modules:       Paths_basic_prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/basic-prelude-0.7.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/basic-prelude-0.7.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/basic-prelude-0.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-basic-prelude
hs-libraries:         HSbasic-prelude-0.7.0-AWll56bMwLJADdeHnl7DBM
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    filepath-1.4.300.1 hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-basic-prelude/html/basic-prelude.haddock

haddock-html:         /usr/share/doc/haskell-basic-prelude/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
